@@ -5,7 +5,7 @@
  * $Author: kou $
  * $Date: 2008-09-19 12:56:27 $
  *
- * Copyright 2006-2018 Kouhei Sutou <kou@cozmixng.org>
+ * Copyright 2006-2022 Sutou Kouhei <kou@cozmixng.org>
  * Copyright 2005 Øyvind Kolås <pippin@freedesktop.org>
  * Copyright 2004-2005 MenTaLguY <mental@rydia.com>
  *
@@ -53,17 +53,9 @@
 
 RB_CAIRO_BEGIN_DECLS
 
-#if defined(RUBY_CAIRO_PLATFORM_WIN32) && !defined(RB_CAIRO_PLATFORM_WIN32)
-#  define RB_CAIRO_PLATFORM_WIN32 RUBY_CAIRO_PLATFORM_WIN32
-#endif
-
-#if defined(RUBY_CAIRO_STATIC_COMPILATION) && !defined(RB_CAIRO_STATIC_COMPILATION)
-#  define RB_CAIRO_STATIC_COMPILATION RUBY_CAIRO_STATIC_COMPILATION
-#endif
-
-#if defined(RB_CAIRO_PLATFORM_WIN32) && !defined(RB_CAIRO_STATIC_COMPILATION)
+#ifdef __WIN32__
 #  ifdef RB_CAIRO_COMPILATION
-#    define RB_CAIRO_VAR __declspec(dllexport)
+#    define RB_CAIRO_VAR extern __declspec(dllexport)
 #  else
 #    define RB_CAIRO_VAR extern __declspec(dllimport)
 #  endif
@@ -72,8 +64,8 @@ RB_CAIRO_BEGIN_DECLS
 #endif
 
 #define RB_CAIRO_VERSION_MAJOR 1
-#define RB_CAIRO_VERSION_MINOR 15
-#define RB_CAIRO_VERSION_MICRO 13
+#define RB_CAIRO_VERSION_MINOR 17
+#define RB_CAIRO_VERSION_MICRO 8
 
 RB_CAIRO_VAR VALUE rb_mCairo;
 RB_CAIRO_VAR VALUE rb_cCairo_Context;
@@ -125,7 +117,6 @@ RB_CAIRO_VAR VALUE rb_cCairo_GLTextureSurface;
 RB_CAIRO_VAR VALUE rb_cCairo_DRMSurface;
 RB_CAIRO_VAR VALUE rb_cCairo_TeeSurface;
 RB_CAIRO_VAR VALUE rb_cCairo_XMLSurface;
-RB_CAIRO_VAR VALUE rb_cCairo_SkiaSurface;
 RB_CAIRO_VAR VALUE rb_cCairo_SubSurface;
 RB_CAIRO_VAR VALUE rb_cCairo_Device;
 RB_CAIRO_VAR VALUE rb_cCairo_DRMDevice;
